@@ -6,10 +6,6 @@
 *
 * OpenOffice.org - a multi-platform office productivity suite
 *
-* $RCSfile: mysqlc_driver.cxx,v $
-*
-* $Revision: 1.1.2.5 $
-*
 * This file is part of OpenOffice.org.
 *
 * OpenOffice.org is free software: you can redistribute it and/or modify
@@ -39,12 +35,10 @@ using namespace connectivity::mysqlc;
 using ::rtl::OUString;
 #include <stdio.h>
 
-#include <preextstl.h>
 #include <cppconn/exception.h>
 #ifdef SYSTEM_MYSQL_CPPCONN
     #include <mysql_driver.h>
 #endif
-#include <postextstl.h>
 
 
 /* {{{ MysqlCDriver::MysqlCDriver() -I- */
@@ -102,7 +96,7 @@ Sequence< OUString > MysqlCDriver::getSupportedServiceNames_Static()
     // which service is supported 
     // for more information @see com.sun.star.sdbc.Driver
     Sequence< OUString > aSNS(1);
-    aSNS[0] = OUString::createFromAscii("com.sun.star.sdbc.Driver");
+    aSNS[0] = OUString(RTL_CONSTASCII_USTRINGPARAM("com.sun.star.sdbc.Driver"));
     return aSNS;
 }
 /* }}} */
@@ -152,7 +146,7 @@ void MysqlCDriver::impl_initCppConn_lck_throw()
 #else
     if ( !m_bAttemptedLoadCppConn )
     {
-        const ::rtl::OUString sModuleName = ::rtl::OUString::createFromAscii( CPPCONN_LIB );
+        const ::rtl::OUString sModuleName(RTL_CONSTASCII_USTRINGPARAM( CPPCONN_LIB ));
         m_hCppConnModule = osl_loadModuleRelative( &thisModule, sModuleName.pData, 0 );
         m_bAttemptedLoadCppConn = true;
     }
@@ -160,7 +154,7 @@ void MysqlCDriver::impl_initCppConn_lck_throw()
     // attempted to load - was it successful?
     if ( !m_hCppConnModule )
     {
-        OSL_ENSURE( false, "MysqlCDriver::impl_initCppConn_lck_throw: could not load the " CPPCONN_LIB " library!");
+        OSL_FAIL( "MysqlCDriver::impl_initCppConn_lck_throw: could not load the " CPPCONN_LIB " library!");
         throw SQLException(
             ::rtl::OUString( RTL_CONSTASCII_USTRINGPARAM( "Unable to load the " CPPCONN_LIB " library." ) ),
             *this,
@@ -177,7 +171,7 @@ void MysqlCDriver::impl_initCppConn_lck_throw()
     const FGetMySQLDriver pFactoryFunction = (FGetMySQLDriver)( osl_getFunctionSymbol( m_hCppConnModule, sSymbolName.pData ) );
     if ( !pFactoryFunction )
     {
-        OSL_ENSURE( false, "MysqlCDriver::impl_initCppConn_lck_throw: could not find the factory symbol in " CPPCONN_LIB "!");
+        OSL_FAIL( "MysqlCDriver::impl_initCppConn_lck_throw: could not find the factory symbol in " CPPCONN_LIB "!");
         throw SQLException(
             ::rtl::OUString( RTL_CONSTASCII_USTRINGPARAM( CPPCONN_LIB " is invalid: missing the driver factory function." ) ),
             *this,
@@ -243,7 +237,7 @@ sal_Bool SAL_CALL MysqlCDriver::acceptsURL(const OUString& url)
         throw(SQLException, RuntimeException)
 {
     OSL_TRACE("MysqlCDriver::acceptsURL");
-    return (!url.compareTo(OUString::createFromAscii("sdbc:mysqlc:"), sizeof("sdbc:mysqlc:")-1));
+    return (!url.compareTo(OUString(RTL_CONSTASCII_USTRINGPARAM("sdbc:mysqlc:")), sizeof("sdbc:mysqlc:")-1));
 }
 /* }}} */
 
@@ -260,14 +254,14 @@ Sequence< DriverPropertyInfo > SAL_CALL MysqlCDriver::getPropertyInfo(const OUSt
                 OUString(RTL_CONSTASCII_USTRINGPARAM("Hostname"))
                 ,OUString(RTL_CONSTASCII_USTRINGPARAM("Name of host"))
                 ,sal_True
-                ,OUString::createFromAscii("localhost")
+                ,OUString(RTL_CONSTASCII_USTRINGPARAM("localhost"))
                 ,Sequence< OUString >())
             );
         aDriverInfo.push_back(DriverPropertyInfo(
                 OUString(RTL_CONSTASCII_USTRINGPARAM("Port"))
                 ,OUString(RTL_CONSTASCII_USTRINGPARAM("Port"))
                 ,sal_True
-                ,OUString::createFromAscii("3306")
+                ,OUString(RTL_CONSTASCII_USTRINGPARAM("3306"))
                 ,Sequence< OUString >())
             );
         return Sequence< DriverPropertyInfo >(&(aDriverInfo[0]),aDriverInfo.size());
