@@ -71,10 +71,10 @@ const DeviceInfo& GraphicCollector::GetDeviceInfo( const Reference< XComponentCo
     return aDeviceInfo;
 }
 
-void ImpAddEntity( std::vector< GraphicCollector::GraphicEntity >& rGraphicEntities, Reference< XGraphic >& rxGraphic, const GraphicSettings& rGraphicSettings, const GraphicCollector::GraphicUser& rUser )
+void ImpAddEntity( std::vector< GraphicCollector::GraphicEntity >& rGraphicEntities, const GraphicSettings& rGraphicSettings, const GraphicCollector::GraphicUser& rUser )
 {
     const rtl::OUString aGraphicURL( rUser.maGraphicURL );
-    const rtl::OUString sPackageURL( OUString::createFromAscii( "vnd.sun.star.GraphicObject:" ) );
+    const rtl::OUString sPackageURL( RTL_CONSTASCII_USTRINGPARAM("vnd.sun.star.GraphicObject:") );
 
     if ( rGraphicSettings.mbEmbedLinkedGraphics || ( !aGraphicURL.getLength() || aGraphicURL.match( sPackageURL, 0 ) ) )
     {
@@ -90,11 +90,11 @@ void ImpAddEntity( std::vector< GraphicCollector::GraphicEntity >& rGraphicEntit
                 aIter->maUser.push_back( rUser );
                 break;
             }
-            aIter++;
+            ++aIter;
         }
         if ( aIter == rGraphicEntities.end() )
         {
-            GraphicCollector::GraphicEntity aEntity( rxGraphic, rUser );
+            GraphicCollector::GraphicEntity aEntity( rUser );
             rGraphicEntities.push_back( aEntity );
         }
     }
@@ -134,7 +134,7 @@ void ImpAddGraphicEntity( const Reference< XComponentContext >& rxMSF, Reference
         }
         aUser.maGraphicCropLogic = aGraphicCropLogic;
         aUser.maLogicalSize = aLogicalSize;
-        ImpAddEntity( rGraphicEntities, xGraphic, rGraphicSettings, aUser );
+        ImpAddEntity( rGraphicEntities, rGraphicSettings, aUser );
     }
 }
 
@@ -199,7 +199,7 @@ void ImpAddFillBitmapEntity( const Reference< XComponentContext >& rxMSF, const
                         aUser.mbFillBitmap = sal_True;
                         aUser.maLogicalSize = aLogicalSize;
                         aUser.mxPagePropertySet = rxPagePropertySet;
-                        ImpAddEntity( rGraphicEntities, xGraphic, rGraphicSettings, aUser );
+                        ImpAddEntity( rGraphicEntities, rGraphicSettings, aUser );
                     }
                 }
             }
@@ -340,12 +340,12 @@ void GraphicCollector::CollectGraphics( const Reference< XComponentContext >& rx
                     }
                     else
                         aGraphicIter->mbRemoveCropArea = sal_False;
-                    aGUIter++;
+                    ++aGUIter;
                 }
             }
             if ( !aGraphicIter->mbRemoveCropArea )
                 aGraphicIter->maGraphicCropLogic = text::GraphicCrop( 0, 0, 0, 0 );
-            aGraphicIter++;
+            ++aGraphicIter;
         }
     }
     catch ( Exception& )
